@@ -477,7 +477,8 @@ SimSolve <- function(design, interval, b, generate, analyse, summarise,
                      type = ifelse(.Platform$OS.type == 'windows', 'PSOCK', 'FORK'),
                      maxiter = 100L, check.interval = TRUE,
                      predCI = .95, predCI.tol = NULL, lastSolve = NULL,
-                     verbose = TRUE, control = list(), ...){
+                     verbose = interactive(),
+                     control = list(), ...){
 
     # robust <- FALSE
     org.opts <- options()
