@@ -278,9 +278,9 @@ Summarise <- function(condition, results, fixed_objects) NULL
 #
 # }
 mainsim <- function(index, condition, generate, analyse, fixed_objects, max_errors, save_results_out_rootdir,
-                    save, allow_na, allow_nan, save_seeds, save_seeds_dirname, load_seed,
+                    save, allow_na, allow_nan, save_seeds, save_seeds_dirname, load_seed, max_time, max_time.start,
                     warnings_as_errors, store_Random.seeds, store_warning_seeds, use_try, include_replication_index,
-                    p = NULL, future = FALSE, allow_gen_errors = TRUE){
+                    useGenerate, useAnalyseHandler, p = NULL, future = FALSE, allow_gen_errors = TRUE){
 
     if(!is.null(p)) p(sprintf("replication = %g", index))
     if(include_replication_index) condition$REPLICATION <- index
@@ -307,10 +307,12 @@ mainsim <- function(index, condition, generate, analyse, fixed_objects, max_erro
         }
         if(!is.null(load_seed))
             .GlobalEnv$.Random.seed <- load_seed
-        simlist <- if(allow_gen_errors)
-            try(withCallingHandlers(generate(condition=condition,
-                                                        fixed_objects=fixed_objects), warning=wHandler), TRUE)
-        else generate(condition=condition, fixed_objects=fixed_objects)
+        simlist <- if(useGenerate){
+            if(allow_gen_errors)
+                try(withCallingHandlers(generate(condition=condition,
+                                                            fixed_objects=fixed_objects), warning=wHandler), TRUE)
+            else generate(condition=condition, fixed_objects=fixed_objects)
+        } else NA
         if(!use_try){
             if(is(simlist, 'try-error')){
                 .GlobalEnv$.Random.seed <- current_Random.seed
@@ -335,8 +337,11 @@ mainsim <- function(index, condition, generate, analyse, fixed_objects, max_erro
             try_error_seeds <- rbind(try_error_seeds, current_Random.seed)
             next
         }
-        res <- try(withCallingHandlers(analyse(dat=simlist, condition=condition,
-                           fixed_objects=fixed_objects), warning=wHandler), silent=TRUE)
+        res <- if(useAnalyseHandler)
+            try(withCallingHandlers(analyse(dat=simlist, condition=condition,
+                               fixed_objects=fixed_objects), warning=wHandler), silent=TRUE)
+        else try(analyse(dat=simlist, condition=condition,
+                         fixed_objects=fixed_objects), silent=TRUE)
         if(!valid_results(res))
             stop("Invalid object returned from Analyse()", call.=FALSE)
         if(!use_try){
@@ -419,3 +424,12 @@ mainsim <- function(index, condition, generate, analyse, fixed_objects, max_erro
         return(res)
     }
 }
+
+mainsim_maxtime <- function(max_time, max_time.start, ...){
+    st <- proc.time()['elapsed']
+    time_left <- max_time - (st - max_time.start)
+    out <- R.utils::withTimeout(mainsim(...),
+                                timeout = time_left,
+                                onTimeout = 'warning')
+    out
+}
