@@ -272,6 +272,18 @@
 #' # list saved files
 #' dir('sim/')
 #'
+#' # Also works if the replication input were a suitable vector (not run)
+#' if(FALSE){
+#'     reps <- c(rep(10, 14), 100)
+#'     cbind(Design5, reps)
+#'     sapply(1:3, \(arrayID)
+#'         runArraySimulation(design=Design5, replications=reps,
+#'           generate=Generate, analyse=Analyse,
+#'           summarise=Summarise, iseed=iseed, arrayID=arrayID,
+#'           filename='condition', dirname='sim', array2row=array2row)) |> invisible()
+#' }
+#'
+#'
 #' # note that all row conditions are still stored separately, though note that
 #' #  arrayID is now 2 instead
 #' condition14 <- readRDS('sim/condition-14.rds')
@@ -295,7 +307,7 @@ runArraySimulation <- function(design, ..., replications,
                                parallel = FALSE, cl = NULL,
                                ncores = parallelly::availableCores(omit = 1L),
                                save_details = list(), control = list(),
-                               verbose = ifelse(interactive(), FALSE, TRUE)){
+                               verbose = interactive()){
     dots <- list(...)
     if(parallel && ncores == 1L) parallel <- FALSE
     if(!is.null(dots$save_results) && isTRUE(dots$save_results))
@@ -317,12 +329,13 @@ runArraySimulation <- function(design, ..., replications,
     stopifnot(nrow(design) > 1L)
     stopifnot("arrayID is not a single integer identifier"=
                   length(arrayID) == 1L && is.numeric(arrayID) && !is.na(arrayID))
+    if(length(replications) == 1)
+        replications <- rep(replications, nrow(design))
     rowpick <- array2row(arrayID)
     filename_suffix <- paste0("-", rowpick)
     stopifnot(!missing(replications))
-    if(length(replications) > 1L)
-        replications <- replications[rowpick]
     stopifnot(rowpick %in% 1L:nrow(design))
+    stopifnot(nrow(design) == length(replications))
     if(!is.null(filename))
         filename <- paste0(filename, filename_suffix)
     if(!is.null(dirname)){
@@ -332,12 +345,6 @@ runArraySimulation <- function(design, ..., replications,
         filename <- gsub("//", "/", filename)
     }
     save_details$arrayID <- arrayID
-    if(parallel){
-        if(is.null(cl)){
-            cl <- parallel::makeCluster(ncores, type="SOCK")
-            on.exit(parallel::stopCluster(cl), add=TRUE)
-        }
-    }
     max_time.start <- proc.time()[3L]
     if(!is.null(control$max_time))
         control$max_time.start <- max_time.start
@@ -346,9 +353,9 @@ runArraySimulation <- function(design, ..., replications,
         seed <- genSeeds(design, iseed=iseed, arrayID=row)
         dsub <- design[row, , drop=FALSE]
         attr(dsub, 'Design.ID') <- attr(design, 'Design.ID')[row]
-        ret <- runSimulation(design=dsub, replications=replications, seed=seed,
+        ret <- runSimulation(design=dsub, replications=replications[row], seed=seed,
                              verbose=verbose, save_details=save_details,
-                             parallel=parallel, cl=cl,
+                             parallel=parallel, ncores=ncores, cl=cl,
                              control=control, save=FALSE, resume=FALSE, ...)
         attr(ret, 'extra_info')$number_of_conditions <- nrow(design)
         if(addArrayInfo && (is.null(dots$store_results) ||
