@@ -223,6 +223,11 @@
 #'   However, it is the responsibility of the user to use \code{plan(sequential)} to reset the
 #'   computing plan when the jobs are completed
 #'
+#' @param not_parallel integer vector indicating which rows in the \code{design}
+#'   object should not be run in parallel. This is useful when some version of
+#'   \code{parallel} is used, however the overhead that tags along with parallel processing
+#'   results in higher processing times than simply running the simulation with one core.
+#'
 #' @param cl cluster object defined by \code{\link{makeCluster}} used to run code in parallel
 #'   (ignored if using the \code{\link[future]{future}} package approach).
 #'   If \code{NULL} and \code{parallel = TRUE}, a local cluster object will be defined which
@@ -258,6 +263,15 @@
 #'   When notification is set to \code{'condition'} or \code{'complete'}, the \code{notifier}
 #'   argument must be supplied with a valid notifier object (or a list of notifier objects).
 #'
+#' @param check.globals logical; should the functions be inspected for potential global variable usage?
+#'   Using global object definitions will raise issues with parallel processing, and therefore
+#'   any global object to be use in the simulation should either be defined within the code
+#'   itself of included in the \code{fixed_objects} input. Setting this value to \code{TRUE} will
+#'   return a character vector of potentially problematic objects/functions that appear global, the
+#'   latter of which can be ignored. Careful inspection of this list may prove useful in tracking down
+#'   object export issues
+#'
+#'
 #' @param notifier A notifier object (or a list of notifier objects, allowing for multiple
 #'   notification methods) required when \code{notification} is not set to \code{"none"}.
 #'   See \code{listAvailableNotifiers} for a list of available notifiers and how to use them.
@@ -617,7 +631,8 @@
 #'   of all the simulation results for each condition if \code{nrow(Design) > 1}; otherwise, if
 #'   \code{nrow(Design) == 1} or \code{Design} was missing the \code{results} object will be stored as-is
 #'
-#' @param verbose logical; print messages to the R console? Default is \code{TRUE}
+#' @param verbose logical; print messages to the R console? Default is \code{TRUE} when
+#'  in interactive mode
 #'
 #' @return a \code{tibble} from the \code{dplyr} package (also of class \code{'SimDesign'})
 #'   with the original \code{design} conditions in the left-most columns,
@@ -1002,10 +1017,11 @@ runSimulation <- function(design, replications, generate, analyse, summarise,
                           store_results = TRUE, save_results = FALSE,
                           parallel = FALSE, ncores = parallelly::availableCores(omit = 1L),
                           cl = NULL, notification = 'none', notifier = NULL,
-                          beep = FALSE, sound = 1,
+                          beep = FALSE, sound = 1, check.globals = FALSE,
                           CI = .95, seed = NULL, boot_method='none', boot_draws = 1000L,
                           max_errors = 50L, resume = TRUE, save_details = list(),
-                          control = list(), progress = TRUE, verbose = TRUE)
+                          control = list(), not_parallel = NULL, progress = TRUE,
+                          verbose = interactive())
 {
     max_time.start <- if(is.null(control$max_time.start)) proc.time()[3L] else control$max_time.start
     stopifnot(!missing(analyse))
@@ -1297,6 +1313,7 @@ runSimulation <- function(design, replications, generate, analyse, summarise,
     } else stopifnot(length(unique(design$ID)) == nrow(design))
     use_try  <- debug != 'error'
     if(debug != 'none' && use_try){
+        max_errors <- 5L
         save <- save_results <- save_seeds <- FALSE
         if(!(debug %in% 'summarise')) parallel <- MPI <- useFuture <- FALSE
         if(debug == 'all'){
@@ -1323,6 +1340,12 @@ runSimulation <- function(design, replications, generate, analyse, summarise,
                 message(sprintf("\nNumber of parallel clusters in use: %i", length(cl)))
         }
     }
+    if(check.globals){
+        globals <- unique(c(codetools::findGlobals(generate, merge=FALSE)[['variables']],
+                     codetools::findGlobals(analyse, merge=FALSE)[['variables']],
+                     codetools::findGlobals(summarise, merge=FALSE)[['variables']]))
+        return(setdiff(globals, c(names(design), names(fixed_objects))))
+    }
     Result_list <- vector('list', nrow(design))
     names(Result_list) <- rownames(design)
     time0 <- time1 <- proc.time()[3L]
@@ -1459,10 +1482,12 @@ runSimulation <- function(design, replications, generate, analyse, summarise,
                                            else design[i,],
                                          replications=replications[i],
                                          fixed_objects=fixed_objects,
-                                         cl=cl, MPI=MPI, .options.mpi=.options.mpi, seed=seed,
+                                         cl=if(i %in% not_parallel) NULL else cl,
+                                         MPI=MPI, .options.mpi=.options.mpi, seed=seed,
                                          boot_draws=boot_draws, boot_method=boot_method, CI=CI,
                                          save=save, allow_na=allow_na, allow_nan=allow_nan,
-                                         save_results=save_results, useFuture=useFuture,
+                                         save_results=save_results,
+                                         useFuture=if(i %in% not_parallel) FALSE else useFuture,
                                          store_Random.seeds=store_Random.seeds,
                                          store_warning_seeds=store_warning_seeds,
                                          save_results_out_rootdir=out_rootdir,
@@ -1498,11 +1523,13 @@ runSimulation <- function(design, replications, generate, analyse, summarise,
                             condition=if(was_tibble) dplyr::as_tibble(design[i,]) else design[i,],
                             replications=replications[i],
                             fixed_objects=fixed_objects,
-                            cl=cl, MPI=MPI, .options.mpi=.options.mpi, seed=seed,
+                            cl=if(i %in% not_parallel) NULL else cl,
+                            MPI=MPI, .options.mpi=.options.mpi, seed=seed,
                             store_Random.seeds=store_Random.seeds,
                             boot_method=boot_method, boot_draws=boot_draws, CI=CI,
                             save=save, allow_na=allow_na, allow_nan=allow_nan,
-                            save_results=save_results, useFuture=useFuture,
+                            save_results=save_results,
+                            useFuture=if(i %in% not_parallel) FALSE else useFuture,
                             store_warning_seeds=store_warning_seeds,
                             save_results_out_rootdir = out_rootdir,
                             save_results_dirname=save_results_dirname,
